@@ -93,7 +93,7 @@ static QObject *global_object_50(QQmlEngine *, QJSEngine *)
 class QtSensorsDeclarativeModule : public QQmlExtensionPlugin
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface" FILE "plugin.json")
+    Q_PLUGIN_METADATA(IID QQmlExtensionInterface_iid FILE "plugin.json")
 public:
     QtSensorsDeclarativeModule(QObject *parent = 0) : QQmlExtensionPlugin(parent) { initResources(); }
     virtual void registerTypes(const char *uri)
@@ -222,10 +222,10 @@ public:
 
         qmlRegisterType           <QmlSensorGesture            >(package, major, minor, "SensorGesture");
 
-        // Register the 5.7 interfaces
+        // Register the 5.8 interfaces
         // No API changes, just reintroduce existing interfaces from 5.2
-        // Implicitly registers 5.3 - 5.6 too
-        minor = 7;
+        // Implicitly registers 5.3 - 5.7 too
+        minor = 8;
         qmlRegisterType           <QmlAltimeter                >(package, major, minor, "Altimeter");
     }
 };
