@@ -40,11 +40,11 @@
 #ifndef IOSMAGNETOMETER_H
 #define IOSMAGNETOMETER_H
 
-#include <CoreMotion/CMMotionManager.h>
-
 #include <qsensorbackend.h>
 #include <qmagnetometer.h>
 
+@class CMMotionManager;
+
 QT_BEGIN_NAMESPACE
 
 class IOSMagnetometer : public QSensorBackend
